@@ -106,29 +106,81 @@ def pyaqua_version():
 pyaqua_version()
 
 
-def sitelist(sname):
+def sitelist(sname, status):
     sid_list = []
     status_list = []
     response = requests.get("https://ocean-systems.uc.r.appspot.com/api/sites")
+    stat_type = ["maintenance", "deployed", "shipped", "lost"]
+    if status is not None and status not in stat_type:
+        sys.exit(
+            "Status type not supported choose from: maintenance|deployed|shipped|lost"
+        )
     for items in response.json():
         if items["sensorId"] is not None:
-            sid_list.append({items["name"]: items["id"]})
-            status_list.append(items["status"])
+            if status is not None and items["status"] == status:
+                sid_list.append({items["name"]: items["id"]})
+                status_list.append(items["status"])
+            elif status is None:
+                sid_list.append({items["name"]: items["id"]})
+                status_list.append(items["status"])
     for site in sid_list:
         for name, sid in site.items():
             if sname is not None:
                 rat = fuzz.ratio(sname.lower(), name.lower())
-            if sname is not None and rat > 75:
-                print(f"{name}: {sid}")
+                if sname.lower() in name.lower() or rat > 75:
+                    print(f"{name}: {sid}")
             elif sname is None:
                 print(f"{name}: {sid}")
     print("\n" + f"Found a total of {len(sid_list)} sites with spotters" + "\n")
-    print("Spoter status distribution :")
+    print("Spotter status distribution :")
     print(json.dumps(Counter(status_list)))
 
 
 def sitelist_from_parser(args):
-    sitelist(sname=args.name)
+    sitelist(sname=args.name, status=args.status)
+
+
+# Site alert
+def sitealert(level):
+    sid_list = []
+    status_list = []
+    if level is None:
+        level = 1  # only pick sites with alert
+    response = requests.get(
+        "https://ocean-systems.uc.r.appspot.com/api/collections/heat-stress-tracker",
+        headers=headers,
+    )
+    if response.status_code == 200:
+        for alert_sites in response.json()["sites"]:
+            if alert_sites["sensorId"] is not None:
+                if alert_sites["collectionData"]["alert"] == 0:
+                    alert_level = "no alert"
+                elif alert_sites["collectionData"]["alert"] == 1:
+                    alert_level = "watch"
+                elif alert_sites["collectionData"]["alert"] == 2:
+                    alert_level = "warning"
+                elif alert_sites["collectionData"]["alert"] == 3:
+                    alert_level = "Level-1"
+                elif alert_sites["collectionData"]["alert"] == 4:
+                    alert_level = "Level-2"
+                if alert_sites["collectionData"]["alert"] >= level:
+                    sid_list.append({alert_sites["name"]: alert_sites["id"]})
+                    status_list.append(alert_level)
+    for site in sid_list:
+        for name, sid in site.items():
+            print(f"{name}: {sid}")
+    print(
+        "\n"
+        + f"Found a total of {len(sid_list)} sites with spotters & active alert level >= {level}"
+        + "\n"
+    )
+    print("Level Key ===> 0: No alert, 1: watch, 2: warning, 3:Level-1, 4:Level-2")
+    print("\n" + "Alert level distribution :")
+    print(json.dumps(Counter(status_list)))
+
+
+def sitealert_from_parser(args):
+    sitealert(level=args.level)
 
 
 # Get a quick check on a site
@@ -241,6 +293,11 @@ def site_timeseries(delta, sid, dtype, fpath):
     past_utc = past_utc.strftime("%Y-%m-%dT%H:%M:%SZ")
     print(f"Time series from {past_utc} to {current_utc}")
 
+    response = requests.get(f"https://ocean-systems.uc.r.appspot.com/api/sites/{sid}")
+    if response.status_code == 200:
+        resp = response.json()["polygon"]["coordinates"]
+        lng = resp[0]
+        lat = resp[1]
     if dtype is not None:
         if dtype == "temp":
             metrics = "bottom_temperature,top_temperature"
@@ -275,11 +332,17 @@ def site_timeseries(delta, sid, dtype, fpath):
                 print(f"Processing noaa_{metric}_{sid}")
                 fname = os.path.join(fpath, f"spotter_{metric}_{sid}.csv")
                 df = pd.DataFrame(resp["noaa"][metric])
+                if lat and lng is not None:
+                    df["latitude"] = lat
+                    df["longitude"] = lng
                 df.to_csv(fname, index=False)
             if resp["spotter"][metric]:
                 print(f"Processing spotter_{metric}_{sid}")
                 fname = os.path.join(fpath, f"spotter_{metric}_{sid}.csv")
                 df = pd.DataFrame(resp["spotter"][metric])
+                if lat and lng is not None:
+                    df["latitude"] = lat
+                    df["longitude"] = lng
                 df.to_csv(fname, index=False)
     else:
         print(
@@ -300,8 +363,26 @@ def main(args=None):
     )
     optional_named = parser_sitelist.add_argument_group("Optional named arguments")
     optional_named.add_argument("--name", help="Pass site name", default=None)
+    optional_named.add_argument(
+        "--status",
+        help="Site status from maintenance|deployed|shipped|lost",
+        default=None,
+    )
     parser_sitelist.set_defaults(func=sitelist_from_parser)
 
+    parser_sitealert = subparsers.add_parser(
+        "site-alert", help="Print site alerts for sites with spotters"
+    )
+    optional_named = parser_sitealert.add_argument_group("Optional named arguments")
+    optional_named.add_argument(
+        "--level",
+        help="Level 0-4 no-alert|watch|warning|Level-1|Level-2",
+        default=None,
+        type=int,
+        choices=range(0, 5),
+    )
+    parser_sitealert.set_defaults(func=sitealert_from_parser)
+
     parser_siteinfo = subparsers.add_parser(
         "site-info", help="Print detailed information for a site"
     )
